<?php

namespace Drupal\homebox\Form;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The Homebox Form.
 *
 * @ingroup homebox
 */
class HomeboxForm extends ContentEntityForm {

  /**
   * The Current User object.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * {@inheritDoc}
   */
  public function __construct(EntityRepositoryInterface $entity_repository, EntityTypeBundleInfoInterface $entity_type_bundle_info = NULL, TimeInterface $time = NULL, AccountInterface $current_user) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('entity.repository'),
          $container->get('entity_type.bundle.info'),
          $container->get('datetime.time'),
          $container->get('current_user'),
      );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $this->messenger()->addWarning(
          "This form is mainly used for debugging
      and selecting the layout to use.\n
      Therefore, most of the values here cannot be changed!\n
      Please use the \"View\" tab to configure the Portlets."
      );

    /**
    * @var \Drupal\homebox\Entity\HomeboxInterface $homebox
    */
    $homebox = $this->entity;
    /**
    * @var \Drupal\homebox\Entity\HomeboxTypeInterface $homeboxType
    */
    $homeboxType = $homebox->getHomeboxType();

    if ($this->operation == 'edit') {
      $form['#title'] = $this->t(
            '<em>Edit @type Homebox:</em> @title', [
              '@type' => $homeboxType->label(),
              '@title' => $homebox->label(),
            ]
        );
    }

    // Changed must be sent to the client, for later overwrite error checking.
    $form['changed'] = [
      '#type' => 'hidden',
      '#default_value' => $homebox->getChangedTime(),
    ];
    $form = parent::form($form, $form_state);

    switch ($this->operation) {
      case 'add':
        $form['label']['#access'] = FALSE;
        $form['isPresetDefault']['widget']['value']['#default_value'] = FALSE;
        $form['isPreset']['widget']['value']['#default_value'] = TRUE;
        break;

      case 'edit':
        $form['owner']['#disabled'] = TRUE;
        $form['isPreset']['#disabled'] = TRUE;
        break;
    }
    $form['label']['#disabled'] = TRUE;
    $form['isPresetDefault']['#disabled'] = TRUE;
    $form['creator']['#disabled'] = TRUE;
    $form['created']['#disabled'] = TRUE;
    $form['portlets']['#disabled'] = TRUE;
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $homebox = $this->entity;

    $status = parent::save($form, $form_state);

    switch ($status) {
      case SAVED_NEW:
        $this->messenger()->addMessage(
              $this->t(
                  'Created the %label Homebox.', [
                    '%label' => $homebox->label(),
                  ]
              )
          );
        break;

      default:
        $this->messenger()->addMessage(
              $this->t(
                  'Saved the %label Homebox.', [
                    '%label' => $homebox->label(),
                  ]
              )
          );
    }
    $form_state->setRedirect('entity.homebox.collection');
    return $status;
  }

}
